==> sharepoint_utils-0.1-py3-none-any.whl: sharepoint_utils/main.py <==
#########################################################################################

# Import necessary modules for authentication and working with SharePoint files
from office365.sharepoint.files.creation_information import FileCreationInformation
from office365.runtime.auth.authentication_context import AuthenticationContext
from office365.sharepoint.client_context import ClientContext
from office365.sharepoint.files.file import File
from io import StringIO
import pandas as pd
import io


#########################################################################################

def connect_to_sharepoint(username, password, site_address):
    """
    This function connects to a SharePoint site using the provided username, password, and site address.
    
    :param username: The username to authenticate with SharePoint.
    :param password: The password to authenticate with SharePoint.
    :param site_address: The address of the SharePoint site.
    :return: ClientContext object if successful, None otherwise.
    """
    
    # Define SharePoint base URL
    sharepoint_base_url = site_address

    # Specify SharePoint user credentials
    sharepoint_user = username
    sharepoint_password = password

    # Authenticate with SharePoint
    ctx_auth = AuthenticationContext(sharepoint_base_url)
    if ctx_auth.acquire_token_for_user(sharepoint_user, sharepoint_password):
        ctx = ClientContext(sharepoint_base_url, ctx_auth)
        web = ctx.web
        ctx.load(web)
        ctx.execute_query()

        # Print a message indicating successful connection to SharePoint along with the web title
        print('Connected to SharePoint: ', web.properties['Title'])
        return ctx
    else:
        print("Failed to authenticate with SharePoint.")
        return None

# Example usage:
# ctx = connect_to_sharepoint('your_username', 'your_password', 'https://your_sharepoint_site_url')

#########################################################################################

def combine_files_into_dataframe(ctx, folder_url):
    """
    Combine files from a SharePoint folder into a single pandas DataFrame.
    
    :param ctx: ClientContext object authenticated with SharePoint.
    :param folder_url: Server-relative URL of the SharePoint folder containing files.
    :return: Combined pandas DataFrame if successful, None otherwise.
    """
    try:
        # Get the folder object using the provided folder URL
        folder = ctx.web.get_folder_by_server_relative_url(folder_url)

        # Get the collection of files in the folder
        files = folder.files

        # Load the files collection
        ctx.load(files)

        # Execute the query to retrieve the files
        ctx.execute_query()

        # Initialize an empty list to store individual DataFrames
        all_data_frames = []

        # Iterate through each file in the folder
        for file in files:
            # Get the name of the file
            file_name = file.properties["Name"]

            # Open the file and get its content
            response = File.open_binary(ctx, file.serverRelativeUrl)
            file_content = response.content

            # Check the file extension to determine the file type
            if file_name.lower().endswith('.csv'):
                # Read CSV file content into a pandas DataFrame using BytesIO
                df = pd.read_csv(io.BytesIO(file_content))
            elif file_name.lower().endswith('.xlsx'):
                # Read XLSX file content into a pandas DataFrame
                df = pd.read_excel(io.BytesIO(file_content))
            else:
                # Skip files with unsupported extensions
                continue

            # Append the DataFrame to the list
            all_data_frames.append(df)

        # Concatenate all individual DataFrames into a single DataFrame
        combined_df = pd.concat(all_data_frames, ignore_index=True)

        # Return the combined DataFrame
        return combined_df

    # Handle any exceptions that may occur during file reading
    except Exception as e:
        print('Problem reading files: ', e)
        return None

# Specify the folder path in SharePoint containing the files to be combined into a DataFrame
#folder_path = 'relative folder/path'

# Call the combine_files_into_dataframe function with the SharePoint client context and folder path as inputs
#df = combine_files_into_dataframe(ctx, folder_path)

#########################################################################################

from io import StringIO
from pandas import DataFrame

def upload_dataframe_to_sharepoint(ctx, folder, dataframe, file_name):
    """
    This function uploads a pandas DataFrame to a SharePoint folder as a CSV file.

    Parameters:
    ctx (ClientContext): The SharePoint ClientContext.
    folder (Folder): The SharePoint folder where the file will be uploaded.
    dataframe (DataFrame): The pandas DataFrame to be uploaded.
    file_name (str): The name of the file to be created.
    """

    try:
        # Convert the DataFrame to a CSV string
        csv_buffer = StringIO()
        dataframe.to_csv(csv_buffer, index=False)
        file_content = csv_buffer.getvalue().encode('utf-8-sig')

        # Upload the file to the folder
        file = folder.upload_file(file_name, file_content).execute_query()
        print(f"File has been uploaded into: {file.serverRelativeUrl}")
    
    except Exception as e:
        print(f"An error occurred while uploading the file: {str(e)}")


# define folder path
#folder_path = /folder_path/

# Get the SharePoint folder
#folder = ctx.web.get_folder_by_server_relative_url(folder_path).select(["Exists"]).get().execute_query()

# Call the function to upload the DataFrame to the SharePoint folder
#upload_dataframe_to_sharepoint(ctx, folder, df, 'your_file_name.csv')

#########################################################################################

==> sharepoint_utils-1.1-py3-none-any.whl: sharepoint_utils/main.py <==
#########################################################################################
# Import necessary modules for authentication and working with SharePoint files
from office365.runtime.auth.authentication_context import AuthenticationContext
from office365.sharepoint.client_context import ClientContext
from io import StringIO

#########################################################################################

def connect_to_sharepoint(username, password, site_address):
    """
    This function connects to a SharePoint site using the provided username, password, and site address.
    
    :param username: The username to authenticate with SharePoint.
    :param password: The password to authenticate with SharePoint.
    :param site_address: The address of the SharePoint site.
    :return: ClientContext object if successful, None otherwise.
    """
    # Define SharePoint base URL
    sharepoint_base_url = site_address
    # Specify SharePoint user credentials
    sharepoint_user = username
    sharepoint_password = password
    # Authenticate with SharePoint
    ctx_auth = AuthenticationContext(sharepoint_base_url)
    if ctx_auth.acquire_token_for_user(sharepoint_user, sharepoint_password):
        ctx = ClientContext(sharepoint_base_url, ctx_auth)
        web = ctx.web
        ctx.load(web)
        ctx.execute_query()
        # Print a message indicating successful connection to SharePoint along with the web title
        print('Connected to SharePoint: ', web.properties['Title'])
        return ctx
    else:
        print("Failed to authenticate with SharePoint.")
        return None

#########################################################################################

def upload_dataframe_to_sharepoint(ctx, folder_path, dataframe, file_name):
    """
    This function uploads a pandas DataFrame to a SharePoint folder as a CSV file.

    Parameters:
    ctx (ClientContext): The SharePoint ClientContext.
    folder_path (str): The server-relative URL of the SharePoint folder where the file will be uploaded.
    dataframe (DataFrame): The pandas DataFrame to be uploaded.
    file_name (str): The name of the file to be created.
    """
    try:
        # Get the SharePoint folder
        folder = ctx.web.get_folder_by_server_relative_url(folder_path).select(["Exists"]).get().execute_query()
        
        # Convert the DataFrame to a CSV string
        csv_buffer = StringIO()
        dataframe.to_csv(csv_buffer, index=False)
        file_content = csv_buffer.getvalue().encode('utf-8-sig')

        # Upload the file to the folder
        file = folder.upload_file(file_name, file_content).execute_query()
        print(f"File has been uploaded into: {file.serverRelativeUrl}")
    
    except Exception as e:
        print(f"An error occurred while uploading the file: {str(e)}")

#########################################################################################

def copy_files_within_folders(ctx, file_path, upload_to_path):
    """
    Copies files from one location to another using SharePoint client context.

    Args:
    ctx: SharePoint client context object.
    file_path: List of file paths to be copied. | Type: List
    upload_to_path: Path where files will be copied. | Type: String

    Returns:
    None
    """

    for files in file_path:
        try:
            # Get the file from the source location
            file_from = ctx.web.get_file_by_server_relative_url(files)
            
            # Get the destination folder
            folder_to = ctx.web.get_folder_by_server_relative_url(upload_to_path)
            # Alternatively, you can specify the destination folder as a string like this:
            # folder_to = "Shared Documents/archive/2002/02"
            
            # Copy the file to the destination folder
            file_from.copyto(folder_to, True).execute_query()
            
            # Print a message indicating that the file has been copied
            print("{0} copied into: '{1}'".format(file_from, upload_to_path))
        except Exception as e:
            print("Error copying file {0}: {1}".format(files, e))

#########################################################################################
